<img src="https://github.com/matchms/matchms_extras/blob/main/images/matchms_extras_logo.png" width="600">

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/matchms/matchms_extras/CI%20Build)
![GitHub](https://img.shields.io/github/license/matchms/matchms_extras)

# matchms_extras

Additional functionalities to be used with [matchms](https://github.com/matchms/matchms), but which either in scope and/or in code quality and/or in degree of unit testing do not match the criteria we have for matchms.

## Installation (soon)

```
pip install matchms_extras
```

